import { Directive, ElementRef, forwardRef, HostListener, Inject, NgModule } from '@angular/core';
import { FormsModule, NG_VALUE_ACCESSOR } from '@angular/forms';
import { registerElement } from '@nativescript/angular';
import { BaseValueAccessor } from '@nativescript/angular/forms/value-accessors';
function convertToInt(value) {
    var normalizedValue;
    if (value === undefined || value === null) {
        normalizedValue = 0;
    }
    else {
        if (typeof value === 'number') {
            normalizedValue = value;
        }
        else {
            var parsedValue = parseInt(value.toString(), 10);
            normalizedValue = isNaN(parsedValue) ? 0 : parsedValue;
        }
    }
    return Math.round(normalizedValue);
}
registerElement('CheckBox', function () { return require('../checkbox').CheckBox; });
var CHECKED_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return CheckedValueAccessor; }),
    multi: true,
};
var CheckedValueAccessor = (function (_super) {
    __extends(CheckedValueAccessor, _super);
    function CheckedValueAccessor(elementRef) {
        var _this = _super.call(this, elementRef.nativeElement) || this;
        _this.onTouched = function () { };
        return _this;
    }
    CheckedValueAccessor.prototype.checkedChangeListener = function (event) {
        this.onChange(event.value);
    };
    CheckedValueAccessor.prototype.writeValue = function (value) {
        this.view.checked = value;
    };
    CheckedValueAccessor.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    __decorate([
        HostListener('checkedChange', ['$event']),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", [Object]),
        __metadata("design:returntype", void 0)
    ], CheckedValueAccessor.prototype, "checkedChangeListener", null);
    CheckedValueAccessor = __decorate([
        Directive({
            selector: 'CheckBox[ngModel], CheckBox[formControlName], CheckBox[formControl], checkBox[ngModel], checkBox[formControlName], checkBox[formControl], check-box[ngModel], check-box[formControlName], check-box[formControl]',
            providers: [CHECKED_VALUE_ACCESSOR],
        }),
        __param(0, Inject(ElementRef)),
        __metadata("design:paramtypes", [ElementRef])
    ], CheckedValueAccessor);
    return CheckedValueAccessor;
}(BaseValueAccessor));
export { CheckedValueAccessor };
var TNSCheckBoxModule = (function () {
    function TNSCheckBoxModule() {
    }
    TNSCheckBoxModule = __decorate([
        NgModule({
            declarations: [CheckedValueAccessor],
            providers: [],
            imports: [FormsModule],
            exports: [FormsModule, CheckedValueAccessor],
        })
    ], TNSCheckBoxModule);
    return TNSCheckBoxModule;
}());
export { TNSCheckBoxModule };
